@@ -1,4 +1,4 @@
-from .brcode import brcode
+from .brcode import *
 
 
 __short_description__ = (
